

# get google calendar API credentials for your account here:
# https://developers.google.com/calendar/quickstart/python



# ---- sample code from google unless otherwise noted: ----

from __future__ import print_function

# --- from me: ---
import maya # for help with time
import serial # to talk to arduino
import time # to sleep for a second
# --- end from me ---

import datetime
import pickle
import os.path
from googleapiclient.discovery import build
from google_auth_oauthlib.flow import InstalledAppFlow
from google.auth.transport.requests import Request

# --- from me: ---

# Arduino serial connection:
serialLink = serial.Serial('/dev/tty.usbmodem14401', 9600)

# --- end from me ---

# If modifying these scopes, delete the file token.pickle.
SCOPES = ['https://www.googleapis.com/auth/calendar.readonly']

def main():
    """Shows basic usage of the Google Calendar API.
    Prints the start and name of the next 10 events on the user's calendar.
    """
    creds = None
    # The file token.pickle stores the user's access and refresh tokens, and is
    # created automatically when the authorization flow completes for the first
    # time.
    if os.path.exists('token.pickle'):
        with open('token.pickle', 'rb') as token:
            creds = pickle.load(token)
    # If there are no (valid) credentials available, let the user log in.
    if not creds or not creds.valid:
        if creds and creds.expired and creds.refresh_token:
            creds.refresh(Request())
        else:
            flow = InstalledAppFlow.from_client_secrets_file(
                'credentials.json', SCOPES)
            creds = flow.run_local_server(port=0)
        # Save the credentials for the next run
        with open('token.pickle', 'wb') as token:
            pickle.dump(creds, token)

    service = build('calendar', 'v3', credentials=creds)

    # --- from me + google: ---
    # modified it into an endless loop to keep checking
    while(True):
        # added a check of initial time (so that network wait doesn't slow us down)
        dtinit = maya.now()

        # modified getting events to just one
        # Call the Calendar API
        now = datetime.datetime.utcnow().isoformat() + 'Z' # 'Z' indicates UTC time
        print('Getting the next event')
        events_result = service.events().list(calendarId='primary', timeMin=now,
                                            maxResults=1, singleEvents=True,
                                            orderBy='startTime').execute()
        events = events_result.get('items', [])

        if not events:
            print('No upcoming events found.')
        for event in events:
            start = event['start'].get('dateTime', event['start'].get('date'))
            print(start, event['summary'])
            # added the section below to check the time difference and react
            dtstart = maya.parse(start)
            dtnow = maya.now()
            tduntil = dtstart-dtnow
            minutesleft = int(tduntil.total_seconds()//60)
            print(minutesleft)
            if(minutesleft==5):
                print("ding")
                serialLink.write(str.encode("AC"))
            if(minutesleft==4):
                print("dong")
                serialLink.write(str.encode("ACEC"))
            if(minutesleft==1):
                print("dong")
                serialLink.write(str.encode("CDEDEF"))
            if(minutesleft==0):
                print("NOW!")
                serialLink.write(str.encode("ABCDEF FEDCBA"))
        waiting = True
        while(waiting):
            time.sleep(1)
            timepassed = maya.now() - dtinit
            if(int(timepassed.total_seconds())%10 == 0):
                print(int(timepassed.total_seconds()))

            waiting = (timepassed.total_seconds()<60)        


        

if __name__ == '__main__':
    main()


# ---- end sample code from google ----